From: Con Kolivas <kernel@kolivas.org>
To: linux kernel mailing list <linux-kernel@vger.kernel.org>
Cc: Andrew Morton <akpm@osdl.org>
Subject: [PATCH]O20.3int
Date: Tue, 16 Sep 2003 11:00:44 +1000 [thread overview]
Message-ID: <200309161100.44312.kernel@kolivas.org> (raw)
[-- Attachment #1: Type: text/plain, Size: 111 bytes --]
Yep I really hate doing this, sorry. This is what I was supposed to do in
O20.2int.
applies to O20.2int
Con
[-- Attachment #2: patch-O20.2-O20.3int --]
[-- Type: text/x-diff, Size: 703 bytes --]
--- linux-2.6.0-test5-mm2-O20.2/kernel/sched.c 2003-09-16 09:27:57.000000000 +1000
+++ linux-2.6.0-test5-mm2-O20.3/kernel/sched.c 2003-09-16 10:50:49.000000000 +1000
@@ -1426,11 +1426,11 @@ void scheduler_tick(int user_ticks, int
* equal priority.
*
* This only applies to tasks in the interactive
* delta range with at least MIN_TIMESLICE to requeue.
*/
if (TASK_INTERACTIVE(p) && !((task_timeslice(p) -
p->time_slice) % TIMESLICE_GRANULARITY(p)) &&
- (p->time_slice >= MIN_TIMESLICE) &&
+ (p->time_slice >= TIMESLICE_GRANULARITY(p)) &&
(p->array == rq->active)) {
dequeue_task(p, rq->active);
reply other threads:[~2003-09-16 0:52 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=200309161100.44312.kernel@kolivas.org \
--to=kernel@kolivas.org \
--cc=akpm@osdl.org \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1426,11 +1426,11 @@ void scheduler_tick(int user_ticks, int
*
* This only applies to tasks in the interactive
- * delta range with at least MIN_TIMESLICE to requeue.
+ * delta range with at least TIMESLICE_GRANULARITY to requeue.
*/
if (TASK_INTERACTIVE(p) && !((task_timeslice(p) -
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox